@@ -1,7 +1,10 @@
 import html
+import inspect
+import ipaddress
 import json
 import typing
 import warnings
+from http import HTTPStatus
 from urllib.parse import urlparse
 
 from django.conf import settings
@@ -19,9 +22,9 @@ from django.contrib.auth.password_validation import (
     validate_password,
 )
 from django.contrib.sites.shortcuts import get_current_site
-from django.core.exceptions import FieldDoesNotExist
+from django.core.exceptions import FieldDoesNotExist, PermissionDenied
 from django.core.mail import EmailMessage, EmailMultiAlternatives
-from django.http import HttpResponse, HttpResponseRedirect
+from django.http import HttpRequest, HttpResponse, HttpResponseRedirect
 from django.http.request import validate_host
 from django.shortcuts import resolve_url
 from django.template import TemplateDoesNotExist
@@ -38,7 +41,11 @@ from allauth.core import context
 from allauth.core.internal import ratelimit
 from allauth.core.internal.adapter import BaseAdapter
 from allauth.core.internal.cryptokit import generate_user_code
-from allauth.core.internal.httpkit import headed_redirect_response, is_headless_request
+from allauth.core.internal.httpkit import (
+    HTTP_USER_AGENT_MAX_LENGTH,
+    headed_redirect_response,
+    is_headless_request,
+)
 from allauth.utils import generate_unique_username, import_attribute
 
 
@@ -439,16 +446,16 @@ class DefaultAccountAdapter(BaseAdapter):
         status = response.status_code
 
         if redirect_to:
-            status = 200
+            status = HTTPStatus.OK
             resp["location"] = redirect_to
         if form:
             if request.method == "POST":
                 if form.is_valid():
-                    status = 200
+                    status = HTTPStatus.OK
                 else:
-                    status = 400
+                    status = HTTPStatus.BAD_REQUEST
             else:
-                status = 200
+                status = HTTPStatus.OK
             resp["form"] = self.ajax_response_form(form)
             if hasattr(response, "render"):
                 response.render()
@@ -774,12 +781,19 @@ class DefaultAccountAdapter(BaseAdapter):
     def get_client_ip(self, request) -> str:
         x_forwarded_for = request.META.get("HTTP_X_FORWARDED_FOR")
         if x_forwarded_for:
-            ip = x_forwarded_for.split(",")[0]
+            ip_value = x_forwarded_for.split(",")[0]
         else:
-            ip = request.META.get("REMOTE_ADDR")
-        return ip
+            ip_value = request.META["REMOTE_ADDR"]
 
-    def get_http_user_agent(self, request):
+        # Try to parse the value as an IP address to make sure it's a valid one.
+        try:
+            ip_addr = ipaddress.ip_address(ip_value)
+        except ValueError:
+            raise PermissionDenied(f"Invalid IP address: {ip_value!r}")
+        else:
+            return str(ip_addr)
+
+    def get_http_user_agent(self, request: HttpRequest) -> str:
         return request.META.get("HTTP_USER_AGENT", "Unspecified")
 
     def generate_emailconfirmation_key(self, email):
@@ -795,7 +809,7 @@ class DefaultAccountAdapter(BaseAdapter):
             from allauth.mfa import app_settings as mfa_settings
 
             ret.append("allauth.mfa.stages.AuthenticateStage")
-            if mfa_settings.TRUST_ENABLED:
+            if mfa_settings._TRUST_STAGE_ENABLED:
                 ret.append("allauth.mfa.stages.TrustStage")
 
             if mfa_settings.PASSKEY_SIGNUP_ENABLED:
@@ -849,7 +863,9 @@ class DefaultAccountAdapter(BaseAdapter):
         ctx = {
             "timestamp": timezone.now(),
             "ip": self.get_client_ip(self.request),
-            "user_agent": self.get_http_user_agent(self.request),
+            "user_agent": self.get_http_user_agent(self.request)[
+                :HTTP_USER_AGENT_MAX_LENGTH
+            ],
         }
         if context:
             ctx.update(context)
@@ -873,12 +889,23 @@ class DefaultAccountAdapter(BaseAdapter):
         """
         return generate_user_code()
 
-    def generate_phone_verification_code(self) -> str:
+    def generate_phone_verification_code(self, *, user, phone: str) -> str:
         """
         Generates a new phone verification code.
         """
         return generate_user_code()
 
+    def _generate_phone_verification_code_compat(self, *, user, phone: str) -> str:
+        sig = inspect.signature(self.generate_phone_verification_code)
+        if len(sig.parameters) == 0:
+            warnings.warn(
+                "generate_phone_verification_code(self) is deprecated, use generate_phone_verification_code(self, *, user, phone)",
+                DeprecationWarning,
+            )
+            return self.generate_phone_verification_code()  # type: ignore[call-arg]
+
+        return self.generate_phone_verification_code(user=user, phone=phone)
+
     def is_login_by_code_required(self, login) -> bool:
         """
         Returns whether or not login-by-code is required for the given
