@@ -7,20 +7,24 @@ from allauth.account.internal.flows import (
     manage_email,
     password_change,
     password_reset,
+    password_reset_by_code,
+    phone_verification,
     reauthentication,
     signup,
 )
 
 
 __all__ = [
-    "password_reset",
-    "password_change",
     "email_verification",
     "email_verification_by_code",
     "login",
     "login_by_code",
     "logout",
-    "signup",
     "manage_email",
+    "password_change",
+    "password_reset",
+    "password_reset_by_code",
+    "phone_verification",
     "reauthentication",
+    "signup",
 ]
