@@ -45,7 +45,13 @@ class PhoneVerificationProcess(AbstractCodeVerificationProcess):
             raise_exception=True,
         )
         adapter = get_adapter()
-        code = adapter.generate_phone_verification_code()
+        if self.user:
+            code = adapter._generate_phone_verification_code_compat(
+                user=self.user,
+                phone=self.phone,
+            )
+        else:
+            code = ""
         self.state["code"] = code
         self.send_sms(skip_enumeration_sms)
         get_adapter().add_message(
