@@ -1,10 +1,11 @@
 """
 Parts derived from socialregistration and authorized by: alen, pinda
 Inspired by:
-    http://github.com/leah/python-oauth/blob/master/oauth/example/client.py
-    http://github.com/facebook/tornado/blob/master/tornado/auth.py
+    https://github.com/leah/python-oauth/blob/master/oauth/example/client.py
+    https://github.com/facebook/tornado/blob/master/tornado/auth.py
 """
 
+from http import HTTPStatus
 from urllib.parse import parse_qsl, urlparse
 
 from django.http import HttpResponseRedirect
@@ -23,8 +24,8 @@ def get_token_prefix(url):
 
     Example:
 
-        The request token url ``http://twitter.com/oauth/request_token``
-        returns ``twitter.com``
+        The request token url ``https://x.com/oauth/request_token``
+        returns ``x.com``
 
     """
     return urlparse(url).netloc
@@ -78,7 +79,7 @@ class OAuthClient:
             rt_url = self.request_token_url + "?" + urlencode(get_params)
             oauth = OAuth1(self.consumer_key, client_secret=self.consumer_secret)
             response = get_adapter().get_requests_session().post(url=rt_url, auth=oauth)
-            if response.status_code not in [200, 201]:
+            if response.status_code not in [HTTPStatus.OK, HTTPStatus.CREATED]:
                 raise OAuthError(
                     _(
                         "Invalid response while obtaining request token"
@@ -107,13 +108,13 @@ class OAuthClient:
             )
             at_url = self.access_token_url
             # Passing along oauth_verifier is required according to:
-            # http://groups.google.com/group/twitter-development-talk/browse_frm/thread/472500cfe9e7cdb9#
+            # https://groups.google.com/group/twitter-development-talk/browse_frm/thread/472500cfe9e7cdb9#
             # Though, the custom oauth_callback seems to work without it?
             oauth_verifier = get_request_param(self.request, "oauth_verifier")
             if oauth_verifier:
                 at_url = at_url + "?" + urlencode({"oauth_verifier": oauth_verifier})
             response = get_adapter().get_requests_session().post(url=at_url, auth=oauth)
-            if response.status_code not in [200, 201]:
+            if response.status_code not in [HTTPStatus.OK, HTTPStatus.CREATED]:
                 raise OAuthError(
                     _("Invalid response while obtaining access token" ' from "%s".')
                     % get_token_prefix(self.request_token_url)
@@ -206,7 +207,7 @@ class OAuth:
         response = getattr(get_adapter().get_requests_session(), method.lower())(
             url, auth=oauth, headers=headers, params=params
         )
-        if response.status_code != 200:
+        if response.status_code != HTTPStatus.OK:
             raise OAuthError(
                 _('No access to private resources at "%s".')
                 % get_token_prefix(self.request_token_url)
