@@ -9,7 +9,7 @@ from allauth.socialaccount.providers.oauth2.views import (
 
 class RedditAdapter(OAuth2Adapter):
     provider_id = "reddit"
-    access_token_url = "https://www.reddit.com/api/v1/access_token"
+    access_token_url = "https://www.reddit.com/api/v1/access_token"  # nosec
     authorize_url = "https://www.reddit.com/api/v1/authorize"
     profile_url = "https://oauth.reddit.com/api/v1/me"
     basic_auth = True
