@@ -12,7 +12,7 @@ class TwitterAccount(ProviderAccount):
         ret = None
         screen_name = self.get_screen_name()
         if screen_name:
-            ret = "http://twitter.com/" + screen_name
+            ret = "https://x.com/" + screen_name
         return ret
 
     def get_avatar_url(self):
@@ -31,15 +31,15 @@ class TwitterAccount(ProviderAccount):
 
 class TwitterProvider(OAuthProvider):
     id = "twitter"
-    name = "Twitter"
+    name = "X"
     account_class = TwitterAccount
     oauth_adapter_class = TwitterOAuthAdapter
 
     def get_auth_url(self, request, action):
         if action == AuthAction.REAUTHENTICATE:
-            url = "https://api.twitter.com/oauth/authorize"
+            url = "https://api.x.com/oauth/authorize"
         else:
-            url = "https://api.twitter.com/oauth/authenticate"
+            url = "https://api.x.com/oauth/authenticate"
         return url
 
     def extract_uid(self, data):
