@@ -1,6 +1,5 @@
 from allauth.socialaccount.providers.oauth.urls import default_urlpatterns
-
-from .provider import VimeoProvider
+from allauth.socialaccount.providers.vimeo.provider import VimeoProvider
 
 
 urlpatterns = default_urlpatterns(VimeoProvider)
