@@ -12,9 +12,9 @@ from allauth.utils import get_request_param
 
 class VKOAuth2Adapter(OAuth2Adapter):
     provider_id = "vk"
-    access_token_url = "https://id.vk.com/oauth2/auth"  # nosec
-    authorize_url = "https://id.vk.com/authorize"
-    profile_url = "https://id.vk.com/oauth2/user_info"
+    access_token_url = "https://id.vk.ru/oauth2/auth"  # nosec
+    authorize_url = "https://id.vk.ru/authorize"
+    profile_url = "https://id.vk.ru/oauth2/user_info"
 
     def get_access_token_data(self, request, app, client, pkce_code_verifier=None):
         code = get_request_param(self.request, "code")
